==> haskell-aeson-better-errors-0.9.1.1-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-better-errors
version:              0.9.1.1
visibility:           public
id:                   aeson-better-errors-0.9.1.1-8FXLhNTDp3y7dHZy3LD2Z6
key:                  aeson-better-errors-0.9.1.1-8FXLhNTDp3y7dHZy3LD2Z6
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  e7e28c1b62468cd08e7199e9d939bac6
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.1-8FXLhNTDp3y7dHZy3LD2Z6
depends:
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j base-4.16.4.0
    bytestring-0.11.4.0 dlist-1.0-HCxoMn9TirQDgPCFxho7O mtl-2.2.2
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR text-1.2.5.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-better-errors
version:              0.9.1.1
visibility:           public
id:                   aeson-better-errors-0.9.1.1-B1sAB2cCNNFAspeY2faFBd
key:                  aeson-better-errors-0.9.1.1-B1sAB2cCNNFAspeY2faFBd
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  1df39a2c6824d25681a9e830685e76c7
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aeson-better-errors-0.9.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.1-B1sAB2cCNNFAspeY2faFBd
depends:
    aeson-2.1.2.1-3YQjfXPQMsb4U9de9kBzUF base-4.16.4.0
    bytestring-0.11.4.0 dlist-1.0-HCxoMn9TirQDgPCFxho7O mtl-2.2.2
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR text-1.2.5.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
